"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var fs_1 = __importDefault(require("fs"));
var path_1 = __importDefault(require("path"));
exports.tryPkg = function (pkg) {
    try {
        return require.resolve(pkg);
    }
    catch (_a) { }
};
exports.isPkgAvailable = function (pkg) { return !!exports.tryPkg(pkg); };
exports.isTsAvailable = exports.tryPkg('typescript');
exports.isReactAvailable = exports.tryPkg('react');
exports.isMdxAvailable = exports.tryPkg('@mdx/mdx') || exports.tryPkg('@mdx/react');
exports.isVueAvailable = exports.tryPkg('vue');
exports.tryFile = function (filePath) {
    if (typeof filePath === 'string') {
        return fs_1.default.existsSync(filePath) ? filePath : '';
    }
    for (var _i = 0, _a = filePath || []; _i < _a.length; _i++) {
        var file = _a[_i];
        if (exports.tryFile(file)) {
            return file;
        }
    }
    return '';
};
// eslint-disable-next-line node/no-deprecated-api
exports.EXTENSIONS = Object.keys(require.extensions);
if (exports.isTsAvailable) {
    exports.EXTENSIONS.unshift('.ts', '.tsx');
}
exports.tryExtensions = function (filepath, extensions) {
    if (extensions === void 0) { extensions = exports.EXTENSIONS; }
    var ext = extensions.find(function (ext) { return fs_1.default.existsSync(filepath + ext); });
    return ext ? filepath + ext : '';
};
exports.identify = function (_) { return !!_; };
var cwd = process.cwd();
exports.findUp = function (searchEntry, searchFile) {
    if (searchFile === void 0) { searchFile = 'package.json'; }
    console.assert(path_1.default.isAbsolute(searchEntry));
    if (!exports.tryFile(searchEntry) ||
        (searchEntry !== cwd && !searchEntry.startsWith(cwd + path_1.default.sep))) {
        return '';
    }
    searchEntry = path_1.default.resolve(fs_1.default.statSync(searchEntry).isDirectory()
        ? searchEntry
        : path_1.default.resolve(searchEntry, '..'));
    do {
        var searched = exports.tryFile(path_1.default.resolve(searchEntry, searchFile));
        if (searched) {
            return searched;
        }
        searchEntry = path_1.default.resolve(searchEntry, '..');
    } while (searchEntry === cwd || searchEntry.startsWith(cwd + path_1.default.sep));
    return '';
};
//# sourceMappingURL=helpers.js.map